=================
Essential Classes
=================

.. autoclass:: sympy.physics.vector.frame.CoordinateSym
   :members:

.. autoclass:: sympy.physics.vector.frame.ReferenceFrame
   :members:

.. autoclass:: sympy.physics.vector.vector.Vector
   :members:

.. autoclass:: sympy.physics.vector.dyadic.Dyadic
   :members:
